# Thumbnail Gallery
[![example_plot_1](documentation/examples/line_plot/plot/plot_1_thumb.png)](documentation/GALLERY.md#plot_1)  [![example_plot_2](documentation/examples/line_plot/plot/plot_2_thumb.png)](documentation/GALLERY.md#plot_2)  [![example_plot_3](documentation/examples/line_plot/plot/plot_3_thumb.png)](documentation/GALLERY.md#plot_3)  [![example_plot_4](documentation/examples/line_plot/plot/plot_4_thumb.png)](documentation/GALLERY.md#plot_4)  [![example_plot_5](documentation/examples/line_plot/plot/plot_5_thumb.png)](documentation/GALLERY.md#plot_5)  [![example_plot_6](documentation/examples/line_plot/plot/plot_6_thumb.png)](documentation/GALLERY.md#plot_6)  [![example_plot_7](documentation/examples/line_plot/plot/plot_7_thumb.png)](documentation/GALLERY.md#plot_7)  [![example_plot_8](documentation/examples/line_plot/plot/plot_8_thumb.png)](documentation/GALLERY.md#plot_8)  [![example_plot_9](documentation/examples/line_plot/plot/plot_9_thumb.png)](documentation/GALLERY.md#plot_9)  [![example_plot_10](documentation/examples/line_plot/plot/plot_10_thumb.png)](documentation/GALLERY.md#plot_10)  [![example_plot_11](documentation/examples/line_plot/plot/plot_11_thumb.png)](documentation/GALLERY.md#plot_11)  [![example_plot_12](documentation/examples/line_plot/plot/plot_12_thumb.png)](documentation/GALLERY.md#plot_12)  [![example_plot3_1](documentation/examples/line_plot/plot3/plot3_1_thumb.png)](documentation/GALLERY.md#plot3_1)  [![example_plot3_2](documentation/examples/line_plot/plot3/plot3_2_thumb.png)](documentation/GALLERY.md#plot3_2)  [![example_plot3_3](documentation/examples/line_plot/plot3/plot3_3_thumb.png)](documentation/GALLERY.md#plot3_3)  [![example_plot3_4](documentation/examples/line_plot/plot3/plot3_4_thumb.png)](documentation/GALLERY.md#plot3_4)  [![example_plot3_5](documentation/examples/line_plot/plot3/plot3_5_thumb.png)](documentation/GALLERY.md#plot3_5)  [![example_plot3_6](documentation/examples/line_plot/plot3/plot3_6_thumb.png)](documentation/GALLERY.md#plot3_6)  [![example_plot3_7](documentation/examples/line_plot/plot3/plot3_7_thumb.png)](documentation/GALLERY.md#plot3_7)  [![example_plot3_8](documentation/examples/line_plot/plot3/plot3_8_thumb.png)](documentation/GALLERY.md#plot3_8)  [![example_plot3_9](documentation/examples/line_plot/plot3/plot3_9_thumb.png)](documentation/GALLERY.md#plot3_9)  [![example_plot3_10](documentation/examples/line_plot/plot3/plot3_10_thumb.png)](documentation/GALLERY.md#plot3_10)  [![example_stairs_1](documentation/examples/line_plot/stairs/stairs_1_thumb.png)](documentation/GALLERY.md#stairs_1)  [![example_stairs_2](documentation/examples/line_plot/stairs/stairs_2_thumb.png)](documentation/GALLERY.md#stairs_2)  [![example_stairs_3](documentation/examples/line_plot/stairs/stairs_3_thumb.png)](documentation/GALLERY.md#stairs_3)  [![example_stairs_4](documentation/examples/line_plot/stairs/stairs_4_thumb.png)](documentation/GALLERY.md#stairs_4)  [![example_stairs_5](documentation/examples/line_plot/stairs/stairs_5_thumb.png)](documentation/GALLERY.md#stairs_5)  [![example_stairs_6](documentation/examples/line_plot/stairs/stairs_6_thumb.png)](documentation/GALLERY.md#stairs_6)  [![example_stairs_7](documentation/examples/line_plot/stairs/stairs_7_thumb.png)](documentation/GALLERY.md#stairs_7)  [![example_stairs_8](documentation/examples/line_plot/stairs/stairs_8_thumb.png)](documentation/GALLERY.md#stairs_8)  [![example_stairs_9](documentation/examples/line_plot/stairs/stairs_9_thumb.png)](documentation/GALLERY.md#stairs_9)  [![example_stairs_10](documentation/examples/line_plot/stairs/stairs_10_thumb.png)](documentation/GALLERY.md#stairs_10)  [![example_errorbar_1](documentation/examples/line_plot/errorbar/errorbar_1_thumb.png)](documentation/GALLERY.md#errorbar_1)  [![example_errorbar_2](documentation/examples/line_plot/errorbar/errorbar_2_thumb.png)](documentation/GALLERY.md#errorbar_2)  [![example_errorbar_3](documentation/examples/line_plot/errorbar/errorbar_3_thumb.png)](documentation/GALLERY.md#errorbar_3)  [![example_errorbar_4](documentation/examples/line_plot/errorbar/errorbar_4_thumb.png)](documentation/GALLERY.md#errorbar_4)  [![example_errorbar_5](documentation/examples/line_plot/errorbar/errorbar_5_thumb.png)](documentation/GALLERY.md#errorbar_5)  [![example_errorbar_6](documentation/examples/line_plot/errorbar/errorbar_6_thumb.png)](documentation/GALLERY.md#errorbar_6)  [![example_errorbar_7](documentation/examples/line_plot/errorbar/errorbar_7_thumb.png)](documentation/GALLERY.md#errorbar_7)  [![example_errorbar_8](documentation/examples/line_plot/errorbar/errorbar_8_thumb.png)](documentation/GALLERY.md#errorbar_8)  [![example_errorbar_9](documentation/examples/line_plot/errorbar/errorbar_9_thumb.png)](documentation/GALLERY.md#errorbar_9)  [![example_errorbar_10](documentation/examples/line_plot/errorbar/errorbar_10_thumb.png)](documentation/GALLERY.md#errorbar_10)  [![example_area_1](documentation/examples/line_plot/area/area_1_thumb.png)](documentation/GALLERY.md#area_1)  [![example_area_2](documentation/examples/line_plot/area/area_2_thumb.png)](documentation/GALLERY.md#area_2)  [![example_area_3](documentation/examples/line_plot/area/area_3_thumb.png)](documentation/GALLERY.md#area_3)  [![example_area_4](documentation/examples/line_plot/area/area_4_thumb.png)](documentation/GALLERY.md#area_4)  [![example_loglog_1](documentation/examples/line_plot/loglog/loglog_1_thumb.png)](documentation/GALLERY.md#loglog_1)  [![example_loglog_2](documentation/examples/line_plot/loglog/loglog_2_thumb.png)](documentation/GALLERY.md#loglog_2)  [![example_loglog_3](documentation/examples/line_plot/loglog/loglog_3_thumb.png)](documentation/GALLERY.md#loglog_3)  [![example_loglog_4](documentation/examples/line_plot/loglog/loglog_4_thumb.png)](documentation/GALLERY.md#loglog_4)  [![example_loglog_5](documentation/examples/line_plot/loglog/loglog_5_thumb.png)](documentation/GALLERY.md#loglog_5)  [![example_loglog_6](documentation/examples/line_plot/loglog/loglog_6_thumb.png)](documentation/GALLERY.md#loglog_6)  [![example_loglog_7](documentation/examples/line_plot/loglog/loglog_7_thumb.png)](documentation/GALLERY.md#loglog_7)  [![example_loglog_8](documentation/examples/line_plot/loglog/loglog_8_thumb.png)](documentation/GALLERY.md#loglog_8)  [![example_loglog_9](documentation/examples/line_plot/loglog/loglog_9_thumb.png)](documentation/GALLERY.md#loglog_9)  [![example_semilogx_1](documentation/examples/line_plot/semilogx/semilogx_1_thumb.png)](documentation/GALLERY.md#semilogx_1)  [![example_semilogy_1](documentation/examples/line_plot/semilogy/semilogy_1_thumb.png)](documentation/GALLERY.md#semilogy_1)  [![example_fplot_1](documentation/examples/line_plot/fplot/fplot_1_thumb.png)](documentation/GALLERY.md#fplot_1)  [![example_fplot_2](documentation/examples/line_plot/fplot/fplot_2_thumb.png)](documentation/GALLERY.md#fplot_2)  [![example_fplot_3](documentation/examples/line_plot/fplot/fplot_3_thumb.png)](documentation/GALLERY.md#fplot_3)  [![example_fplot_4](documentation/examples/line_plot/fplot/fplot_4_thumb.png)](documentation/GALLERY.md#fplot_4)  [![example_fplot_5](documentation/examples/line_plot/fplot/fplot_5_thumb.png)](documentation/GALLERY.md#fplot_5)  [![example_fplot_6](documentation/examples/line_plot/fplot/fplot_6_thumb.png)](documentation/GALLERY.md#fplot_6)  [![example_fplot3_1](documentation/examples/line_plot/fplot3/fplot3_1_thumb.png)](documentation/GALLERY.md#fplot3_1)  [![example_fplot3_2](documentation/examples/line_plot/fplot3/fplot3_2_thumb.png)](documentation/GALLERY.md#fplot3_2)  [![example_fplot3_3](documentation/examples/line_plot/fplot3/fplot3_3_thumb.png)](documentation/GALLERY.md#fplot3_3)  [![example_fplot3_4](documentation/examples/line_plot/fplot3/fplot3_4_thumb.png)](documentation/GALLERY.md#fplot3_4)  [![example_fplot3_5](documentation/examples/line_plot/fplot3/fplot3_5_thumb.png)](documentation/GALLERY.md#fplot3_5)  [![example_fimplicit_1](documentation/examples/line_plot/fimplicit/fimplicit_1_thumb.png)](documentation/GALLERY.md#fimplicit_1)  [![example_fimplicit_2](documentation/examples/line_plot/fimplicit/fimplicit_2_thumb.png)](documentation/GALLERY.md#fimplicit_2)  [![example_fimplicit_3](documentation/examples/line_plot/fimplicit/fimplicit_3_thumb.png)](documentation/GALLERY.md#fimplicit_3)  [![example_fimplicit_4](documentation/examples/line_plot/fimplicit/fimplicit_4_thumb.png)](documentation/GALLERY.md#fimplicit_4)  [![example_histogram_1](documentation/examples/data_distribution/histogram/histogram_1_thumb.png)](documentation/GALLERY.md#histogram_1)  [![example_histogram_2](documentation/examples/data_distribution/histogram/histogram_2_thumb.png)](documentation/GALLERY.md#histogram_2)  [![example_histogram_3](documentation/examples/data_distribution/histogram/histogram_3_thumb.png)](documentation/GALLERY.md#histogram_3)  [![example_histogram_4](documentation/examples/data_distribution/histogram/histogram_4_thumb.png)](documentation/GALLERY.md#histogram_4)  [![example_histogram_5](documentation/examples/data_distribution/histogram/histogram_5_thumb.png)](documentation/GALLERY.md#histogram_5)  [![example_histogram_6](documentation/examples/data_distribution/histogram/histogram_6_thumb.png)](documentation/GALLERY.md#histogram_6)  [![example_histogram_7](documentation/examples/data_distribution/histogram/histogram_7_thumb.png)](documentation/GALLERY.md#histogram_7)  [![example_histogram_8](documentation/examples/data_distribution/histogram/histogram_8_thumb.png)](documentation/GALLERY.md#histogram_8)  [![example_histogram_9](documentation/examples/data_distribution/histogram/histogram_9_thumb.png)](documentation/GALLERY.md#histogram_9)  [![example_histogram_10](documentation/examples/data_distribution/histogram/histogram_10_thumb.png)](documentation/GALLERY.md#histogram_10)  [![example_histogram_11](documentation/examples/data_distribution/histogram/histogram_11_thumb.png)](documentation/GALLERY.md#histogram_11)  [![example_histogram_12](documentation/examples/data_distribution/histogram/histogram_12_thumb.png)](documentation/GALLERY.md#histogram_12)  [![example_histogram_14](documentation/examples/data_distribution/histogram/histogram_14_thumb.png)](documentation/GALLERY.md#histogram_14)  [![example_boxplot_1](documentation/examples/data_distribution/boxplot/boxplot_1_thumb.png)](documentation/GALLERY.md#boxplot_1)  [![example_boxplot_2](documentation/examples/data_distribution/boxplot/boxplot_2_thumb.png)](documentation/GALLERY.md#boxplot_2)  [![example_boxplot_3](documentation/examples/data_distribution/boxplot/boxplot_3_thumb.png)](documentation/GALLERY.md#boxplot_3)  [![example_scatter_1](documentation/examples/data_distribution/scatter/scatter_1_thumb.png)](documentation/GALLERY.md#scatter_1)  [![example_scatter_2](documentation/examples/data_distribution/scatter/scatter_2_thumb.png)](documentation/GALLERY.md#scatter_2)  [![example_scatter_3](documentation/examples/data_distribution/scatter/scatter_3_thumb.png)](documentation/GALLERY.md#scatter_3)  [![example_scatter_4](documentation/examples/data_distribution/scatter/scatter_4_thumb.png)](documentation/GALLERY.md#scatter_4)  [![example_scatter_5](documentation/examples/data_distribution/scatter/scatter_5_thumb.png)](documentation/GALLERY.md#scatter_5)  [![example_scatter_6](documentation/examples/data_distribution/scatter/scatter_6_thumb.png)](documentation/GALLERY.md#scatter_6)  [![example_scatter_7](documentation/examples/data_distribution/scatter/scatter_7_thumb.png)](documentation/GALLERY.md#scatter_7)  [![example_scatter_8](documentation/examples/data_distribution/scatter/scatter_8_thumb.png)](documentation/GALLERY.md#scatter_8)  [![example_scatter3_1](documentation/examples/data_distribution/scatter3/scatter3_1_thumb.png)](documentation/GALLERY.md#scatter3_1)  [![example_scatter3_2](documentation/examples/data_distribution/scatter3/scatter3_2_thumb.png)](documentation/GALLERY.md#scatter3_2)  [![example_scatter3_3](documentation/examples/data_distribution/scatter3/scatter3_3_thumb.png)](documentation/GALLERY.md#scatter3_3)  [![example_scatter3_4](documentation/examples/data_distribution/scatter3/scatter3_4_thumb.png)](documentation/GALLERY.md#scatter3_4)  [![example_scatter3_5](documentation/examples/data_distribution/scatter3/scatter3_5_thumb.png)](documentation/GALLERY.md#scatter3_5)  [![example_scatter3_6](documentation/examples/data_distribution/scatter3/scatter3_6_thumb.png)](documentation/GALLERY.md#scatter3_6)  [![example_binscatter_1](documentation/examples/data_distribution/binscatter/binscatter_1_thumb.png)](documentation/GALLERY.md#binscatter_1)  [![example_binscatter_2](documentation/examples/data_distribution/binscatter/binscatter_2_thumb.png)](documentation/GALLERY.md#binscatter_2)  [![example_binscatter_3](documentation/examples/data_distribution/binscatter/binscatter_3_thumb.png)](documentation/GALLERY.md#binscatter_3)  [![example_binscatter_4](documentation/examples/data_distribution/binscatter/binscatter_4_thumb.png)](documentation/GALLERY.md#binscatter_4)  [![example_binscatter_5](documentation/examples/data_distribution/binscatter/binscatter_5_thumb.png)](documentation/GALLERY.md#binscatter_5)  [![example_binscatter_6](documentation/examples/data_distribution/binscatter/binscatter_6_thumb.png)](documentation/GALLERY.md#binscatter_6)  [![example_binscatter_7](documentation/examples/data_distribution/binscatter/binscatter_7_thumb.png)](documentation/GALLERY.md#binscatter_7)  [![example_plotmatrix_1](documentation/examples/data_distribution/plotmatrix/plotmatrix_1_thumb.png)](documentation/GALLERY.md#plotmatrix_1)  [![example_plotmatrix_2](documentation/examples/data_distribution/plotmatrix/plotmatrix_2_thumb.png)](documentation/GALLERY.md#plotmatrix_2)  [![example_plotmatrix_3](documentation/examples/data_distribution/plotmatrix/plotmatrix_3_thumb.png)](documentation/GALLERY.md#plotmatrix_3)  [![example_plotmatrix_4](documentation/examples/data_distribution/plotmatrix/plotmatrix_4_thumb.png)](documentation/GALLERY.md#plotmatrix_4)  [![example_parallelplot_1](documentation/examples/data_distribution/parallelplot/parallelplot_1_thumb.png)](documentation/GALLERY.md#parallelplot_1)  [![example_parallelplot_2](documentation/examples/data_distribution/parallelplot/parallelplot_2_thumb.png)](documentation/GALLERY.md#parallelplot_2)  [![example_parallelplot_3](documentation/examples/data_distribution/parallelplot/parallelplot_3_thumb.png)](documentation/GALLERY.md#parallelplot_3)  [![example_pie_1](documentation/examples/data_distribution/pie/pie_1_thumb.png)](documentation/GALLERY.md#pie_1)  [![example_pie_2](documentation/examples/data_distribution/pie/pie_2_thumb.png)](documentation/GALLERY.md#pie_2)  [![example_pie_3](documentation/examples/data_distribution/pie/pie_3_thumb.png)](documentation/GALLERY.md#pie_3)  [![example_pie_4](documentation/examples/data_distribution/pie/pie_4_thumb.png)](documentation/GALLERY.md#pie_4)  [![example_pie_5](documentation/examples/data_distribution/pie/pie_5_thumb.png)](documentation/GALLERY.md#pie_5)  [![example_pie_6](documentation/examples/data_distribution/pie/pie_6_thumb.png)](documentation/GALLERY.md#pie_6)  [![example_heatmap_1](documentation/examples/data_distribution/heatmap/heatmap_1_thumb.png)](documentation/GALLERY.md#heatmap_1)  [![example_heatmap_2](documentation/examples/data_distribution/heatmap/heatmap_2_thumb.png)](documentation/GALLERY.md#heatmap_2)  [![example_heatmap_3](documentation/examples/data_distribution/heatmap/heatmap_3_thumb.png)](documentation/GALLERY.md#heatmap_3)  [![example_heatmap_4](documentation/examples/data_distribution/heatmap/heatmap_4_thumb.png)](documentation/GALLERY.md#heatmap_4)  [![example_heatmap_5](documentation/examples/data_distribution/heatmap/heatmap_5_thumb.png)](documentation/GALLERY.md#heatmap_5)  [![example_heatmap_6](documentation/examples/data_distribution/heatmap/heatmap_6_thumb.png)](documentation/GALLERY.md#heatmap_6)  [![example_heatmap_7](documentation/examples/data_distribution/heatmap/heatmap_7_thumb.png)](documentation/GALLERY.md#heatmap_7)  [![example_wordcloud_1](documentation/examples/data_distribution/wordcloud/wordcloud_1_thumb.png)](documentation/GALLERY.md#wordcloud_1)  [![example_wordcloud_3](documentation/examples/data_distribution/wordcloud/wordcloud_3_thumb.png)](documentation/GALLERY.md#wordcloud_3)  [![example_wordcloud_4](documentation/examples/data_distribution/wordcloud/wordcloud_4_thumb.png)](documentation/GALLERY.md#wordcloud_4)  [![example_wordcloud_4](documentation/examples/data_distribution/wordcloud/wordcloud_4_thumb.png)](documentation/GALLERY.md#wordcloud_4)  [![example_bar_1](documentation/examples/discrete_data/bar/bar_1_thumb.png)](documentation/GALLERY.md#bar_1)  [![example_bar_2](documentation/examples/discrete_data/bar/bar_2_thumb.png)](documentation/GALLERY.md#bar_2)  [![example_bar_3](documentation/examples/discrete_data/bar/bar_3_thumb.png)](documentation/GALLERY.md#bar_3)  [![example_bar_4](documentation/examples/discrete_data/bar/bar_4_thumb.png)](documentation/GALLERY.md#bar_4)  [![example_bar_5](documentation/examples/discrete_data/bar/bar_5_thumb.png)](documentation/GALLERY.md#bar_5)  [![example_bar_6](documentation/examples/discrete_data/bar/bar_6_thumb.png)](documentation/GALLERY.md#bar_6)  [![example_bar_7](documentation/examples/discrete_data/bar/bar_7_thumb.png)](documentation/GALLERY.md#bar_7)  [![example_bar_8](documentation/examples/discrete_data/bar/bar_8_thumb.png)](documentation/GALLERY.md#bar_8)  [![example_bar_9](documentation/examples/discrete_data/bar/bar_9_thumb.png)](documentation/GALLERY.md#bar_9)  [![example_bar_10](documentation/examples/discrete_data/bar/bar_10_thumb.png)](documentation/GALLERY.md#bar_10)  [![example_bar_11](documentation/examples/discrete_data/bar/bar_11_thumb.png)](documentation/GALLERY.md#bar_11)  [![example_bar_12](documentation/examples/discrete_data/bar/bar_12_thumb.png)](documentation/GALLERY.md#bar_12)  [![example_bar_13](documentation/examples/discrete_data/bar/bar_13_thumb.png)](documentation/GALLERY.md#bar_13)  [![example_pareto_1](documentation/examples/discrete_data/pareto/pareto_1_thumb.png)](documentation/GALLERY.md#pareto_1)  [![example_pareto_2](documentation/examples/discrete_data/pareto/pareto_2_thumb.png)](documentation/GALLERY.md#pareto_2)  [![example_pareto_3](documentation/examples/discrete_data/pareto/pareto_3_thumb.png)](documentation/GALLERY.md#pareto_3)  [![example_pareto_4](documentation/examples/discrete_data/pareto/pareto_4_thumb.png)](documentation/GALLERY.md#pareto_4)  [![example_stem_1](documentation/examples/discrete_data/stem/stem_1_thumb.png)](documentation/GALLERY.md#stem_1)  [![example_stem_2](documentation/examples/discrete_data/stem/stem_2_thumb.png)](documentation/GALLERY.md#stem_2)  [![example_stem_3](documentation/examples/discrete_data/stem/stem_3_thumb.png)](documentation/GALLERY.md#stem_3)  [![example_stem_4](documentation/examples/discrete_data/stem/stem_4_thumb.png)](documentation/GALLERY.md#stem_4)  [![example_stem_5](documentation/examples/discrete_data/stem/stem_5_thumb.png)](documentation/GALLERY.md#stem_5)  [![example_stem_6](documentation/examples/discrete_data/stem/stem_6_thumb.png)](documentation/GALLERY.md#stem_6)  [![example_stem_7](documentation/examples/discrete_data/stem/stem_7_thumb.png)](documentation/GALLERY.md#stem_7)  [![example_stem_8](documentation/examples/discrete_data/stem/stem_8_thumb.png)](documentation/GALLERY.md#stem_8)  [![example_stem_9](documentation/examples/discrete_data/stem/stem_9_thumb.png)](documentation/GALLERY.md#stem_9)  [![example_stem3_1](documentation/examples/discrete_data/stem3/stem3_1_thumb.png)](documentation/GALLERY.md#stem3_1)  [![example_stem3_2](documentation/examples/discrete_data/stem3/stem3_2_thumb.png)](documentation/GALLERY.md#stem3_2)  [![example_stem3_3](documentation/examples/discrete_data/stem3/stem3_3_thumb.png)](documentation/GALLERY.md#stem3_3)  [![example_stem3_4](documentation/examples/discrete_data/stem3/stem3_4_thumb.png)](documentation/GALLERY.md#stem3_4)  [![example_stem3_5](documentation/examples/discrete_data/stem3/stem3_5_thumb.png)](documentation/GALLERY.md#stem3_5)  [![example_stem3_6](documentation/examples/discrete_data/stem3/stem3_6_thumb.png)](documentation/GALLERY.md#stem3_6)  [![example_stem3_7](documentation/examples/discrete_data/stem3/stem3_7_thumb.png)](documentation/GALLERY.md#stem3_7)  [![example_stem3_8](documentation/examples/discrete_data/stem3/stem3_8_thumb.png)](documentation/GALLERY.md#stem3_8)  [![example_stem3_9](documentation/examples/discrete_data/stem3/stem3_9_thumb.png)](documentation/GALLERY.md#stem3_9)  [![example_stem3_10](documentation/examples/discrete_data/stem3/stem3_10_thumb.png)](documentation/GALLERY.md#stem3_10)  [![example_stem3_11](documentation/examples/discrete_data/stem3/stem3_11_thumb.png)](documentation/GALLERY.md#stem3_11)  [![example_geoplot_1](documentation/examples/geography/geoplot/geoplot_1_thumb.png)](documentation/GALLERY.md#geoplot_1)  [![example_geoplot_2](documentation/examples/geography/geoplot/geoplot_2_thumb.png)](documentation/GALLERY.md#geoplot_2)  [![example_geoplot_3](documentation/examples/geography/geoplot/geoplot_3_thumb.png)](documentation/GALLERY.md#geoplot_3)  [![example_geoplot_4](documentation/examples/geography/geoplot/geoplot_4_thumb.png)](documentation/GALLERY.md#geoplot_4)  [![example_geoplot_5](documentation/examples/geography/geoplot/geoplot_5_thumb.png)](documentation/GALLERY.md#geoplot_5)  [![example_geoplot_6](documentation/examples/geography/geoplot/geoplot_6_thumb.png)](documentation/GALLERY.md#geoplot_6)  [![example_geoplot_7](documentation/examples/geography/geoplot/geoplot_7_thumb.png)](documentation/GALLERY.md#geoplot_7)  [![example_geoscatter_1](documentation/examples/geography/geoscatter/geoscatter_1_thumb.png)](documentation/GALLERY.md#geoscatter_1)  [![example_geoscatter_2](documentation/examples/geography/geoscatter/geoscatter_2_thumb.png)](documentation/GALLERY.md#geoscatter_2)  [![example_geobubble_1](documentation/examples/geography/geobubble/geobubble_1_thumb.png)](documentation/GALLERY.md#geobubble_1)  [![example_geobubble_2](documentation/examples/geography/geobubble/geobubble_2_thumb.png)](documentation/GALLERY.md#geobubble_2)  [![example_geodensityplot_1](documentation/examples/geography/geodensityplot/geodensityplot_1_thumb.png)](documentation/GALLERY.md#geodensityplot_1)  [![example_polarplot_1](documentation/examples/polar_plots/polarplot/polarplot_1_thumb.png)](documentation/GALLERY.md#polarplot_1)  [![example_polarplot_2](documentation/examples/polar_plots/polarplot/polarplot_2_thumb.png)](documentation/GALLERY.md#polarplot_2)  [![example_polarplot_3](documentation/examples/polar_plots/polarplot/polarplot_3_thumb.png)](documentation/GALLERY.md#polarplot_3)  [![example_polarplot_4](documentation/examples/polar_plots/polarplot/polarplot_4_thumb.png)](documentation/GALLERY.md#polarplot_4)  [![example_polarplot_5](documentation/examples/polar_plots/polarplot/polarplot_5_thumb.png)](documentation/GALLERY.md#polarplot_5)  [![example_polarplot_6](documentation/examples/polar_plots/polarplot/polarplot_6_thumb.png)](documentation/GALLERY.md#polarplot_6)  [![example_polarplot_7](documentation/examples/polar_plots/polarplot/polarplot_7_thumb.png)](documentation/GALLERY.md#polarplot_7)  [![example_polarplot_8](documentation/examples/polar_plots/polarplot/polarplot_8_thumb.png)](documentation/GALLERY.md#polarplot_8)  [![example_polarscatter_1](documentation/examples/polar_plots/polarscatter/polarscatter_1_thumb.png)](documentation/GALLERY.md#polarscatter_1)  [![example_polarscatter_2](documentation/examples/polar_plots/polarscatter/polarscatter_2_thumb.png)](documentation/GALLERY.md#polarscatter_2)  [![example_polarscatter_3](documentation/examples/polar_plots/polarscatter/polarscatter_3_thumb.png)](documentation/GALLERY.md#polarscatter_3)  [![example_polarscatter_4](documentation/examples/polar_plots/polarscatter/polarscatter_4_thumb.png)](documentation/GALLERY.md#polarscatter_4)  [![example_polarscatter_5](documentation/examples/polar_plots/polarscatter/polarscatter_5_thumb.png)](documentation/GALLERY.md#polarscatter_5)  [![example_polarscatter_6](documentation/examples/polar_plots/polarscatter/polarscatter_6_thumb.png)](documentation/GALLERY.md#polarscatter_6)  [![example_polarhistogram_1](documentation/examples/polar_plots/polarhistogram/polarhistogram_1_thumb.png)](documentation/GALLERY.md#polarhistogram_1)  [![example_polarhistogram_2](documentation/examples/polar_plots/polarhistogram/polarhistogram_2_thumb.png)](documentation/GALLERY.md#polarhistogram_2)  [![example_polarhistogram_3](documentation/examples/polar_plots/polarhistogram/polarhistogram_3_thumb.png)](documentation/GALLERY.md#polarhistogram_3)  [![example_polarhistogram_4](documentation/examples/polar_plots/polarhistogram/polarhistogram_4_thumb.png)](documentation/GALLERY.md#polarhistogram_4)  [![example_polarhistogram_5](documentation/examples/polar_plots/polarhistogram/polarhistogram_5_thumb.png)](documentation/GALLERY.md#polarhistogram_5)  [![example_compass_1](documentation/examples/polar_plots/compass/compass_1_thumb.png)](documentation/GALLERY.md#compass_1)  [![example_compass_2](documentation/examples/polar_plots/compass/compass_2_thumb.png)](documentation/GALLERY.md#compass_2)  [![example_ezpolar_1](documentation/examples/polar_plots/ezpolar/ezpolar_1_thumb.png)](documentation/GALLERY.md#ezpolar_1)  [![example_ezpolar_2](documentation/examples/polar_plots/ezpolar/ezpolar_2_thumb.png)](documentation/GALLERY.md#ezpolar_2)  [![example_contour_1](documentation/examples/contour_plots/contour/contour_1_thumb.png)](documentation/GALLERY.md#contour_1)  [![example_contour_2](documentation/examples/contour_plots/contour/contour_2_thumb.png)](documentation/GALLERY.md#contour_2)  [![example_contour_3](documentation/examples/contour_plots/contour/contour_3_thumb.png)](documentation/GALLERY.md#contour_3)  [![example_contour_4](documentation/examples/contour_plots/contour/contour_4_thumb.png)](documentation/GALLERY.md#contour_4)  [![example_contour_5](documentation/examples/contour_plots/contour/contour_5_thumb.png)](documentation/GALLERY.md#contour_5)  [![example_contour_6](documentation/examples/contour_plots/contour/contour_6_thumb.png)](documentation/GALLERY.md#contour_6)  [![example_contour_7](documentation/examples/contour_plots/contour/contour_7_thumb.png)](documentation/GALLERY.md#contour_7)  [![example_contour_8](documentation/examples/contour_plots/contour/contour_8_thumb.png)](documentation/GALLERY.md#contour_8)  [![example_contourf_1](documentation/examples/contour_plots/contourf/contourf_1_thumb.png)](documentation/GALLERY.md#contourf_1)  [![example_contourf_2](documentation/examples/contour_plots/contourf/contourf_2_thumb.png)](documentation/GALLERY.md#contourf_2)  [![example_contourf_3](documentation/examples/contour_plots/contourf/contourf_3_thumb.png)](documentation/GALLERY.md#contourf_3)  [![example_contourf_4](documentation/examples/contour_plots/contourf/contourf_4_thumb.png)](documentation/GALLERY.md#contourf_4)  [![example_contourf_5](documentation/examples/contour_plots/contourf/contourf_5_thumb.png)](documentation/GALLERY.md#contourf_5)  [![example_contourf_6](documentation/examples/contour_plots/contourf/contourf_6_thumb.png)](documentation/GALLERY.md#contourf_6)  [![example_fcontour_1](documentation/examples/contour_plots/fcontour/fcontour_1_thumb.png)](documentation/GALLERY.md#fcontour_1)  [![example_fcontour_2](documentation/examples/contour_plots/fcontour/fcontour_2_thumb.png)](documentation/GALLERY.md#fcontour_2)  [![example_fcontour_3](documentation/examples/contour_plots/fcontour/fcontour_3_thumb.png)](documentation/GALLERY.md#fcontour_3)  [![example_fcontour_4](documentation/examples/contour_plots/fcontour/fcontour_4_thumb.png)](documentation/GALLERY.md#fcontour_4)  [![example_fcontour_5](documentation/examples/contour_plots/fcontour/fcontour_5_thumb.png)](documentation/GALLERY.md#fcontour_5)  [![example_fcontour_6](documentation/examples/contour_plots/fcontour/fcontour_6_thumb.png)](documentation/GALLERY.md#fcontour_6)  [![example_fcontour_7](documentation/examples/contour_plots/fcontour/fcontour_7_thumb.png)](documentation/GALLERY.md#fcontour_7)  [![example_fcontour_8](documentation/examples/contour_plots/fcontour/fcontour_8_thumb.png)](documentation/GALLERY.md#fcontour_8)  [![example_fcontour_9](documentation/examples/contour_plots/fcontour/fcontour_9_thumb.png)](documentation/GALLERY.md#fcontour_9)  [![example_fcontour_10](documentation/examples/contour_plots/fcontour/fcontour_10_thumb.png)](documentation/GALLERY.md#fcontour_10)  [![example_fcontour_11](documentation/examples/contour_plots/fcontour/fcontour_11_thumb.png)](documentation/GALLERY.md#fcontour_11)  [![example_feather_1](documentation/examples/vector_fields/feather/feather_1_thumb.png)](documentation/GALLERY.md#feather_1)  [![example_quiver_1](documentation/examples/vector_fields/quiver/quiver_1_thumb.png)](documentation/GALLERY.md#quiver_1)  [![example_quiver_2](documentation/examples/vector_fields/quiver/quiver_2_thumb.png)](documentation/GALLERY.md#quiver_2)  [![example_quiver_3](documentation/examples/vector_fields/quiver/quiver_3_thumb.png)](documentation/GALLERY.md#quiver_3)  [![example_quiver_4](documentation/examples/vector_fields/quiver/quiver_4_thumb.png)](documentation/GALLERY.md#quiver_4)  [![example_quiver_5](documentation/examples/vector_fields/quiver/quiver_5_thumb.png)](documentation/GALLERY.md#quiver_5)  [![example_quiver3_1](documentation/examples/vector_fields/quiver3/quiver3_1_thumb.png)](documentation/GALLERY.md#quiver3_1)  [![example_surf_1](documentation/examples/surfaces/surf/surf_1_thumb.png)](documentation/GALLERY.md#surf_1)  [![example_surf_2](documentation/examples/surfaces/surf/surf_2_thumb.png)](documentation/GALLERY.md#surf_2)  [![example_surf_3](documentation/examples/surfaces/surf/surf_3_thumb.png)](documentation/GALLERY.md#surf_3)  [![example_surf_4](documentation/examples/surfaces/surf/surf_4_thumb.png)](documentation/GALLERY.md#surf_4)  [![example_surf_5](documentation/examples/surfaces/surf/surf_5_thumb.png)](documentation/GALLERY.md#surf_5)  [![example_surf_6](documentation/examples/surfaces/surf/surf_6_thumb.png)](documentation/GALLERY.md#surf_6)  [![example_surfc_1](documentation/examples/surfaces/surfc/surfc_1_thumb.png)](documentation/GALLERY.md#surfc_1)  [![example_surfc_2](documentation/examples/surfaces/surfc/surfc_2_thumb.png)](documentation/GALLERY.md#surfc_2)  [![example_surfc_3](documentation/examples/surfaces/surfc/surfc_3_thumb.png)](documentation/GALLERY.md#surfc_3)  [![example_surfc_4](documentation/examples/surfaces/surfc/surfc_4_thumb.png)](documentation/GALLERY.md#surfc_4)  [![example_mesh_1](documentation/examples/surfaces/mesh/mesh_1_thumb.png)](documentation/GALLERY.md#mesh_1)  [![example_mesh_2](documentation/examples/surfaces/mesh/mesh_2_thumb.png)](documentation/GALLERY.md#mesh_2)  [![example_mesh_3](documentation/examples/surfaces/mesh/mesh_3_thumb.png)](documentation/GALLERY.md#mesh_3)  [![example_mesh_4](documentation/examples/surfaces/mesh/mesh_4_thumb.png)](documentation/GALLERY.md#mesh_4)  [![example_meshc_1](documentation/examples/surfaces/meshc/meshc_1_thumb.png)](documentation/GALLERY.md#meshc_1)  [![example_meshc_2](documentation/examples/surfaces/meshc/meshc_2_thumb.png)](documentation/GALLERY.md#meshc_2)  [![example_meshc_3](documentation/examples/surfaces/meshc/meshc_3_thumb.png)](documentation/GALLERY.md#meshc_3)  [![example_meshz_1](documentation/examples/surfaces/meshz/meshz_1_thumb.png)](documentation/GALLERY.md#meshz_1)  [![example_meshz_2](documentation/examples/surfaces/meshz/meshz_2_thumb.png)](documentation/GALLERY.md#meshz_2)  [![example_meshz_3](documentation/examples/surfaces/meshz/meshz_3_thumb.png)](documentation/GALLERY.md#meshz_3)  [![example_fsurf_1](documentation/examples/surfaces/fsurf/fsurf_1_thumb.png)](documentation/GALLERY.md#fsurf_1)  [![example_fsurf_2](documentation/examples/surfaces/fsurf/fsurf_2_thumb.png)](documentation/GALLERY.md#fsurf_2)  [![example_fsurf_3](documentation/examples/surfaces/fsurf/fsurf_3_thumb.png)](documentation/GALLERY.md#fsurf_3)  [![example_fsurf_4](documentation/examples/surfaces/fsurf/fsurf_4_thumb.png)](documentation/GALLERY.md#fsurf_4)  [![example_fsurf_5](documentation/examples/surfaces/fsurf/fsurf_5_thumb.png)](documentation/GALLERY.md#fsurf_5)  [![example_fsurf_6](documentation/examples/surfaces/fsurf/fsurf_6_thumb.png)](documentation/GALLERY.md#fsurf_6)  [![example_fsurf_7](documentation/examples/surfaces/fsurf/fsurf_7_thumb.png)](documentation/GALLERY.md#fsurf_7)  [![example_fsurf_8](documentation/examples/surfaces/fsurf/fsurf_8_thumb.png)](documentation/GALLERY.md#fsurf_8)  [![example_fmesh_1](documentation/examples/surfaces/fmesh/fmesh_1_thumb.png)](documentation/GALLERY.md#fmesh_1)  [![example_fmesh_2](documentation/examples/surfaces/fmesh/fmesh_2_thumb.png)](documentation/GALLERY.md#fmesh_2)  [![example_fmesh_3](documentation/examples/surfaces/fmesh/fmesh_3_thumb.png)](documentation/GALLERY.md#fmesh_3)  [![example_fmesh_4](documentation/examples/surfaces/fmesh/fmesh_4_thumb.png)](documentation/GALLERY.md#fmesh_4)  [![example_waterfall_1](documentation/examples/surfaces/waterfall/waterfall_1_thumb.png)](documentation/GALLERY.md#waterfall_1)  [![example_waterfall_2](documentation/examples/surfaces/waterfall/waterfall_2_thumb.png)](documentation/GALLERY.md#waterfall_2)  [![example_waterfall_3](documentation/examples/surfaces/waterfall/waterfall_3_thumb.png)](documentation/GALLERY.md#waterfall_3)  [![example_fence_1](documentation/examples/surfaces/fence/fence_1_thumb.png)](documentation/GALLERY.md#fence_1)  [![example_fence_2](documentation/examples/surfaces/fence/fence_2_thumb.png)](documentation/GALLERY.md#fence_2)  [![example_fence_3](documentation/examples/surfaces/fence/fence_3_thumb.png)](documentation/GALLERY.md#fence_3)  [![example_ribbon_1](documentation/examples/surfaces/ribbon/ribbon_1_thumb.png)](documentation/GALLERY.md#ribbon_1)  [![example_ribbon_2](documentation/examples/surfaces/ribbon/ribbon_2_thumb.png)](documentation/GALLERY.md#ribbon_2)  [![example_ribbon_3](documentation/examples/surfaces/ribbon/ribbon_3_thumb.png)](documentation/GALLERY.md#ribbon_3)  [![example_ribbon_4](documentation/examples/surfaces/ribbon/ribbon_4_thumb.png)](documentation/GALLERY.md#ribbon_4)  [![example_graph_1](documentation/examples/graphs/graph/graph_1_thumb.png)](documentation/GALLERY.md#graph_1)  [![example_graph_2](documentation/examples/graphs/graph/graph_2_thumb.png)](documentation/GALLERY.md#graph_2)  [![example_graph_3](documentation/examples/graphs/graph/graph_3_thumb.png)](documentation/GALLERY.md#graph_3)  [![example_graph_4](documentation/examples/graphs/graph/graph_4_thumb.png)](documentation/GALLERY.md#graph_4)  [![example_graph_5](documentation/examples/graphs/graph/graph_5_thumb.png)](documentation/GALLERY.md#graph_5)  [![example_graph_6](documentation/examples/graphs/graph/graph_6_thumb.png)](documentation/GALLERY.md#graph_6)  [![example_digraph_1](documentation/examples/graphs/digraph/digraph_1_thumb.png)](documentation/GALLERY.md#digraph_1)  [![example_digraph_2](documentation/examples/graphs/digraph/digraph_2_thumb.png)](documentation/GALLERY.md#digraph_2)  [![example_digraph_3](documentation/examples/graphs/digraph/digraph_3_thumb.png)](documentation/GALLERY.md#digraph_3)  [![example_imshow_1](documentation/examples/images/imshow/imshow_1_thumb.png)](documentation/GALLERY.md#imshow_1)  [![example_imshow_2](documentation/examples/images/imshow/imshow_2_thumb.png)](documentation/GALLERY.md#imshow_2)  [![example_imshow_3](documentation/examples/images/imshow/imshow_3_thumb.png)](documentation/GALLERY.md#imshow_3)  [![example_imshow_4](documentation/examples/images/imshow/imshow_4_thumb.png)](documentation/GALLERY.md#imshow_4)  [![example_imshow_5](documentation/examples/images/imshow/imshow_5_thumb.png)](documentation/GALLERY.md#imshow_5)  [![example_imshow_6](documentation/examples/images/imshow/imshow_6_thumb.png)](documentation/GALLERY.md#imshow_6)  [![example_imshow_7](documentation/examples/images/imshow/imshow_7_thumb.png)](documentation/GALLERY.md#imshow_7)  [![example_imshow_8](documentation/examples/images/imshow/imshow_8_thumb.png)](documentation/GALLERY.md#imshow_8)  [![example_imshow_9](documentation/examples/images/imshow/imshow_9_thumb.png)](documentation/GALLERY.md#imshow_9)  [![example_imshow_10](documentation/examples/images/imshow/imshow_10_thumb.png)](documentation/GALLERY.md#imshow_10)  [![example_imshow_11](documentation/examples/images/imshow/imshow_11_thumb.png)](documentation/GALLERY.md#imshow_11)  [![example_image_1](documentation/examples/images/image/image_1_thumb.png)](documentation/GALLERY.md#image_1)  [![example_image_2](documentation/examples/images/image/image_2_thumb.png)](documentation/GALLERY.md#image_2)  [![example_image_3](documentation/examples/images/image/image_3_thumb.png)](documentation/GALLERY.md#image_3)  [![example_image_4](documentation/examples/images/image/image_4_thumb.png)](documentation/GALLERY.md#image_4)  [![example_image_5](documentation/examples/images/image/image_5_thumb.png)](documentation/GALLERY.md#image_5)  [![example_imagesc_1](documentation/examples/images/imagesc/imagesc_1_thumb.png)](documentation/GALLERY.md#imagesc_1)  [![example_imagesc_2](documentation/examples/images/imagesc/imagesc_2_thumb.png)](documentation/GALLERY.md#imagesc_2)  [![example_imagesc_3](documentation/examples/images/imagesc/imagesc_3_thumb.png)](documentation/GALLERY.md#imagesc_3)  [![example_imagesc_4](documentation/examples/images/imagesc/imagesc_4_thumb.png)](documentation/GALLERY.md#imagesc_4)  [![example_text_1](documentation/examples/annotations/text/text_1_thumb.png)](documentation/GALLERY.md#text_1)  [![example_text_2](documentation/examples/annotations/text/text_2_thumb.png)](documentation/GALLERY.md#text_2)  [![example_text_3](documentation/examples/annotations/text/text_3_thumb.png)](documentation/GALLERY.md#text_3)  [![example_text_4](documentation/examples/annotations/text/text_4_thumb.png)](documentation/GALLERY.md#text_4)  [![example_text_5](documentation/examples/annotations/text/text_5_thumb.png)](documentation/GALLERY.md#text_5)  [![example_text_6](documentation/examples/annotations/text/text_6_thumb.png)](documentation/GALLERY.md#text_6)  [![example_text_7](documentation/examples/annotations/text/text_7_thumb.png)](documentation/GALLERY.md#text_7)  [![example_text_8](documentation/examples/annotations/text/text_8_thumb.png)](documentation/GALLERY.md#text_8)  [![example_textarrow_1](documentation/examples/annotations/textarrow/textarrow_1_thumb.png)](documentation/GALLERY.md#textarrow_1)  [![example_textarrow_2](documentation/examples/annotations/textarrow/textarrow_2_thumb.png)](documentation/GALLERY.md#textarrow_2)  [![example_rectangle_1](documentation/examples/annotations/rectangle/rectangle_1_thumb.png)](documentation/GALLERY.md#rectangle_1)  [![example_rectangle_2](documentation/examples/annotations/rectangle/rectangle_2_thumb.png)](documentation/GALLERY.md#rectangle_2)  [![example_rectangle_3](documentation/examples/annotations/rectangle/rectangle_3_thumb.png)](documentation/GALLERY.md#rectangle_3)  [![example_rectangle_4](documentation/examples/annotations/rectangle/rectangle_4_thumb.png)](documentation/GALLERY.md#rectangle_4)  [![example_rectangle_5](documentation/examples/annotations/rectangle/rectangle_5_thumb.png)](documentation/GALLERY.md#rectangle_5)  [![example_fill_1](documentation/examples/annotations/fill/fill_1_thumb.png)](documentation/GALLERY.md#fill_1)  [![example_ellipse_1](documentation/examples/annotations/ellipse/ellipse_1_thumb.png)](documentation/GALLERY.md#ellipse_1)  [![example_textbox_1](documentation/examples/annotations/textbox/textbox_1_thumb.png)](documentation/GALLERY.md#textbox_1)  [![example_arrow_1](documentation/examples/annotations/arrow/arrow_1_thumb.png)](documentation/GALLERY.md#arrow_1)  [![example_arrow_2](documentation/examples/annotations/arrow/arrow_2_thumb.png)](documentation/GALLERY.md#arrow_2)  [![example_line_1](documentation/examples/annotations/line/line_1_thumb.png)](documentation/GALLERY.md#line_1)  [![example_title_1](documentation/examples/appearance/labels/title/title_1_thumb.png)](documentation/GALLERY.md#title_1)  [![example_title_2](documentation/examples/appearance/labels/title/title_2_thumb.png)](documentation/GALLERY.md#title_2)  [![example_title_3](documentation/examples/appearance/labels/title/title_3_thumb.png)](documentation/GALLERY.md#title_3)  [![example_title_4](documentation/examples/appearance/labels/title/title_4_thumb.png)](documentation/GALLERY.md#title_4)  [![example_title_5](documentation/examples/appearance/labels/title/title_5_thumb.png)](documentation/GALLERY.md#title_5)  [![example_title_6](documentation/examples/appearance/labels/title/title_6_thumb.png)](documentation/GALLERY.md#title_6)  [![example_title_7](documentation/examples/appearance/labels/title/title_7_thumb.png)](documentation/GALLERY.md#title_7)  [![example_title_8](documentation/examples/appearance/labels/title/title_8_thumb.png)](documentation/GALLERY.md#title_8)  [![example_sgtitle_1](documentation/examples/appearance/labels/sgtitle/sgtitle_1_thumb.png)](documentation/GALLERY.md#sgtitle_1)  [![example_sgtitle_2](documentation/examples/appearance/labels/sgtitle/sgtitle_2_thumb.png)](documentation/GALLERY.md#sgtitle_2)  [![example_xlabel_1](documentation/examples/appearance/labels/xlabel/xlabel_1_thumb.png)](documentation/GALLERY.md#xlabel_1)  [![example_xlabel_2](documentation/examples/appearance/labels/xlabel/xlabel_2_thumb.png)](documentation/GALLERY.md#xlabel_2)  [![example_xlabel_3](documentation/examples/appearance/labels/xlabel/xlabel_3_thumb.png)](documentation/GALLERY.md#xlabel_3)  [![example_xlabel_4](documentation/examples/appearance/labels/xlabel/xlabel_4_thumb.png)](documentation/GALLERY.md#xlabel_4)  [![example_xlabel_5](documentation/examples/appearance/labels/xlabel/xlabel_5_thumb.png)](documentation/GALLERY.md#xlabel_5)  [![example_xlabel_6](documentation/examples/appearance/labels/xlabel/xlabel_6_thumb.png)](documentation/GALLERY.md#xlabel_6)  [![example_xlabel_7](documentation/examples/appearance/labels/xlabel/xlabel_7_thumb.png)](documentation/GALLERY.md#xlabel_7)  [![example_xlabel_8](documentation/examples/appearance/labels/xlabel/xlabel_8_thumb.png)](documentation/GALLERY.md#xlabel_8)  [![example_ylabel_1](documentation/examples/appearance/labels/ylabel/ylabel_1_thumb.png)](documentation/GALLERY.md#ylabel_1)  [![example_ylabel_2](documentation/examples/appearance/labels/ylabel/ylabel_2_thumb.png)](documentation/GALLERY.md#ylabel_2)  [![example_ylabel_3](documentation/examples/appearance/labels/ylabel/ylabel_3_thumb.png)](documentation/GALLERY.md#ylabel_3)  [![example_ylabel_4](documentation/examples/appearance/labels/ylabel/ylabel_4_thumb.png)](documentation/GALLERY.md#ylabel_4)  [![example_ylabel_5](documentation/examples/appearance/labels/ylabel/ylabel_5_thumb.png)](documentation/GALLERY.md#ylabel_5)  [![example_ylabel_6](documentation/examples/appearance/labels/ylabel/ylabel_6_thumb.png)](documentation/GALLERY.md#ylabel_6)  [![example_ylabel_7](documentation/examples/appearance/labels/ylabel/ylabel_7_thumb.png)](documentation/GALLERY.md#ylabel_7)  [![example_ylabel_8](documentation/examples/appearance/labels/ylabel/ylabel_8_thumb.png)](documentation/GALLERY.md#ylabel_8)  [![example_zlabel_1](documentation/examples/appearance/labels/zlabel/zlabel_1_thumb.png)](documentation/GALLERY.md#zlabel_1)  [![example_zlabel_2](documentation/examples/appearance/labels/zlabel/zlabel_2_thumb.png)](documentation/GALLERY.md#zlabel_2)  [![example_zlabel_3](documentation/examples/appearance/labels/zlabel/zlabel_3_thumb.png)](documentation/GALLERY.md#zlabel_3)  [![example_legend_1](documentation/examples/appearance/labels/legend/legend_1_thumb.png)](documentation/GALLERY.md#legend_1)  [![example_legend_2](documentation/examples/appearance/labels/legend/legend_2_thumb.png)](documentation/GALLERY.md#legend_2)  [![example_legend_3](documentation/examples/appearance/labels/legend/legend_3_thumb.png)](documentation/GALLERY.md#legend_3)  [![example_legend_4](documentation/examples/appearance/labels/legend/legend_4_thumb.png)](documentation/GALLERY.md#legend_4)  [![example_legend_5](documentation/examples/appearance/labels/legend/legend_5_thumb.png)](documentation/GALLERY.md#legend_5)  [![example_legend_6](documentation/examples/appearance/labels/legend/legend_6_thumb.png)](documentation/GALLERY.md#legend_6)  [![example_legend_7](documentation/examples/appearance/labels/legend/legend_7_thumb.png)](documentation/GALLERY.md#legend_7)  [![example_legend_8](documentation/examples/appearance/labels/legend/legend_8_thumb.png)](documentation/GALLERY.md#legend_8)  [![example_legend_9](documentation/examples/appearance/labels/legend/legend_9_thumb.png)](documentation/GALLERY.md#legend_9)  [![example_xlim_1](documentation/examples/appearance/axis/xlim/xlim_1_thumb.png)](documentation/GALLERY.md#xlim_1)  [![example_xlim_2](documentation/examples/appearance/axis/xlim/xlim_2_thumb.png)](documentation/GALLERY.md#xlim_2)  [![example_xlim_3](documentation/examples/appearance/axis/xlim/xlim_3_thumb.png)](documentation/GALLERY.md#xlim_3)  [![example_xlim_4](documentation/examples/appearance/axis/xlim/xlim_4_thumb.png)](documentation/GALLERY.md#xlim_4)  [![example_xlim_5](documentation/examples/appearance/axis/xlim/xlim_5_thumb.png)](documentation/GALLERY.md#xlim_5)  [![example_xlim_6](documentation/examples/appearance/axis/xlim/xlim_6_thumb.png)](documentation/GALLERY.md#xlim_6)  [![example_ylim_1](documentation/examples/appearance/axis/ylim/ylim_1_thumb.png)](documentation/GALLERY.md#ylim_1)  [![example_ylim_2](documentation/examples/appearance/axis/ylim/ylim_2_thumb.png)](documentation/GALLERY.md#ylim_2)  [![example_ylim_3](documentation/examples/appearance/axis/ylim/ylim_3_thumb.png)](documentation/GALLERY.md#ylim_3)  [![example_ylim_4](documentation/examples/appearance/axis/ylim/ylim_4_thumb.png)](documentation/GALLERY.md#ylim_4)  [![example_ylim_5](documentation/examples/appearance/axis/ylim/ylim_5_thumb.png)](documentation/GALLERY.md#ylim_5)  [![example_ylim_6](documentation/examples/appearance/axis/ylim/ylim_6_thumb.png)](documentation/GALLERY.md#ylim_6)  [![example_zlim_1](documentation/examples/appearance/axis/zlim/zlim_1_thumb.png)](documentation/GALLERY.md#zlim_1)  [![example_zlim_2](documentation/examples/appearance/axis/zlim/zlim_2_thumb.png)](documentation/GALLERY.md#zlim_2)  [![example_zlim_3](documentation/examples/appearance/axis/zlim/zlim_3_thumb.png)](documentation/GALLERY.md#zlim_3)  [![example_zlim_4](documentation/examples/appearance/axis/zlim/zlim_4_thumb.png)](documentation/GALLERY.md#zlim_4)  [![example_zlim_5](documentation/examples/appearance/axis/zlim/zlim_5_thumb.png)](documentation/GALLERY.md#zlim_5)  [![example_zlim_6](documentation/examples/appearance/axis/zlim/zlim_6_thumb.png)](documentation/GALLERY.md#zlim_6)  [![example_axis_1](documentation/examples/appearance/axis/axis/axis_1_thumb.png)](documentation/GALLERY.md#axis_1)  [![example_axis_2](documentation/examples/appearance/axis/axis/axis_2_thumb.png)](documentation/GALLERY.md#axis_2)  [![example_axis_3](documentation/examples/appearance/axis/axis/axis_3_thumb.png)](documentation/GALLERY.md#axis_3)  [![example_axis_4](documentation/examples/appearance/axis/axis/axis_4_thumb.png)](documentation/GALLERY.md#axis_4)  [![example_axis_5](documentation/examples/appearance/axis/axis/axis_5_thumb.png)](documentation/GALLERY.md#axis_5)  [![example_axis_6](documentation/examples/appearance/axis/axis/axis_6_thumb.png)](documentation/GALLERY.md#axis_6)  [![example_axis_7](documentation/examples/appearance/axis/axis/axis_7_thumb.png)](documentation/GALLERY.md#axis_7)  [![example_axis_8](documentation/examples/appearance/axis/axis/axis_8_thumb.png)](documentation/GALLERY.md#axis_8)  [![example_box_1](documentation/examples/appearance/axis/box/box_1_thumb.png)](documentation/GALLERY.md#box_1)  [![example_box_2](documentation/examples/appearance/axis/box/box_2_thumb.png)](documentation/GALLERY.md#box_2)  [![example_box_3](documentation/examples/appearance/axis/box/box_3_thumb.png)](documentation/GALLERY.md#box_3)  [![example_grid_1](documentation/examples/appearance/grid/grid/grid_1_thumb.png)](documentation/GALLERY.md#grid_1)  [![example_grid_2](documentation/examples/appearance/grid/grid/grid_2_thumb.png)](documentation/GALLERY.md#grid_2)  [![example_grid_3](documentation/examples/appearance/grid/grid/grid_3_thumb.png)](documentation/GALLERY.md#grid_3)  [![example_grid_4](documentation/examples/appearance/grid/grid/grid_4_thumb.png)](documentation/GALLERY.md#grid_4)  [![example_xticks_1](documentation/examples/appearance/grid/xticks/xticks_1_thumb.png)](documentation/GALLERY.md#xticks_1)  [![example_xticks_2](documentation/examples/appearance/grid/xticks/xticks_2_thumb.png)](documentation/GALLERY.md#xticks_2)  [![example_xticks_3](documentation/examples/appearance/grid/xticks/xticks_3_thumb.png)](documentation/GALLERY.md#xticks_3)  [![example_xticks_4](documentation/examples/appearance/grid/xticks/xticks_4_thumb.png)](documentation/GALLERY.md#xticks_4)  [![example_xticks_5](documentation/examples/appearance/grid/xticks/xticks_5_thumb.png)](documentation/GALLERY.md#xticks_5)  [![example_xticks_6](documentation/examples/appearance/grid/xticks/xticks_6_thumb.png)](documentation/GALLERY.md#xticks_6)  [![example_xticks_7](documentation/examples/appearance/grid/xticks/xticks_7_thumb.png)](documentation/GALLERY.md#xticks_7)  [![example_xticks_8](documentation/examples/appearance/grid/xticks/xticks_8_thumb.png)](documentation/GALLERY.md#xticks_8)  [![example_yticks_1](documentation/examples/appearance/grid/yticks/yticks_1_thumb.png)](documentation/GALLERY.md#yticks_1)  [![example_yticks_2](documentation/examples/appearance/grid/yticks/yticks_2_thumb.png)](documentation/GALLERY.md#yticks_2)  [![example_yticks_3](documentation/examples/appearance/grid/yticks/yticks_3_thumb.png)](documentation/GALLERY.md#yticks_3)  [![example_yticks_4](documentation/examples/appearance/grid/yticks/yticks_4_thumb.png)](documentation/GALLERY.md#yticks_4)  [![example_yticks_5](documentation/examples/appearance/grid/yticks/yticks_5_thumb.png)](documentation/GALLERY.md#yticks_5)  [![example_yticks_6](documentation/examples/appearance/grid/yticks/yticks_6_thumb.png)](documentation/GALLERY.md#yticks_6)  [![example_yticks_7](documentation/examples/appearance/grid/yticks/yticks_7_thumb.png)](documentation/GALLERY.md#yticks_7)  [![example_yticks_8](documentation/examples/appearance/grid/yticks/yticks_8_thumb.png)](documentation/GALLERY.md#yticks_8)  [![example_zticks_1](documentation/examples/appearance/grid/zticks/zticks_1_thumb.png)](documentation/GALLERY.md#zticks_1)  [![example_zticks_2](documentation/examples/appearance/grid/zticks/zticks_2_thumb.png)](documentation/GALLERY.md#zticks_2)  [![example_zticks_3](documentation/examples/appearance/grid/zticks/zticks_3_thumb.png)](documentation/GALLERY.md#zticks_3)  [![example_zticks_4](documentation/examples/appearance/grid/zticks/zticks_4_thumb.png)](documentation/GALLERY.md#zticks_4)  [![example_zticks_5](documentation/examples/appearance/grid/zticks/zticks_5_thumb.png)](documentation/GALLERY.md#zticks_5)  [![example_zticks_6](documentation/examples/appearance/grid/zticks/zticks_6_thumb.png)](documentation/GALLERY.md#zticks_6)  [![example_xticklabels_1](documentation/examples/appearance/grid/xticklabels/xticklabels_1_thumb.png)](documentation/GALLERY.md#xticklabels_1)  [![example_xticklabels_2](documentation/examples/appearance/grid/xticklabels/xticklabels_2_thumb.png)](documentation/GALLERY.md#xticklabels_2)  [![example_xticklabels_3](documentation/examples/appearance/grid/xticklabels/xticklabels_3_thumb.png)](documentation/GALLERY.md#xticklabels_3)  [![example_xticklabels_4](documentation/examples/appearance/grid/xticklabels/xticklabels_4_thumb.png)](documentation/GALLERY.md#xticklabels_4)  [![example_yticklabels_1](documentation/examples/appearance/grid/yticklabels/yticklabels_1_thumb.png)](documentation/GALLERY.md#yticklabels_1)  [![example_yticklabels_2](documentation/examples/appearance/grid/yticklabels/yticklabels_2_thumb.png)](documentation/GALLERY.md#yticklabels_2)  [![example_yticklabels_3](documentation/examples/appearance/grid/yticklabels/yticklabels_3_thumb.png)](documentation/GALLERY.md#yticklabels_3)  [![example_yticklabels_4](documentation/examples/appearance/grid/yticklabels/yticklabels_4_thumb.png)](documentation/GALLERY.md#yticklabels_4)  [![example_xtickformat_1](documentation/examples/appearance/grid/xtickformat/xtickformat_1_thumb.png)](documentation/GALLERY.md#xtickformat_1)  [![example_xtickformat_2](documentation/examples/appearance/grid/xtickformat/xtickformat_2_thumb.png)](documentation/GALLERY.md#xtickformat_2)  [![example_xtickformat_3](documentation/examples/appearance/grid/xtickformat/xtickformat_3_thumb.png)](documentation/GALLERY.md#xtickformat_3)  [![example_xtickformat_4](documentation/examples/appearance/grid/xtickformat/xtickformat_4_thumb.png)](documentation/GALLERY.md#xtickformat_4)  [![example_xtickformat_5](documentation/examples/appearance/grid/xtickformat/xtickformat_5_thumb.png)](documentation/GALLERY.md#xtickformat_5)  [![example_ytickformat_1](documentation/examples/appearance/grid/ytickformat/ytickformat_1_thumb.png)](documentation/GALLERY.md#ytickformat_1)  [![example_ytickformat_2](documentation/examples/appearance/grid/ytickformat/ytickformat_2_thumb.png)](documentation/GALLERY.md#ytickformat_2)  [![example_ytickformat_3](documentation/examples/appearance/grid/ytickformat/ytickformat_3_thumb.png)](documentation/GALLERY.md#ytickformat_3)  [![example_ytickformat_4](documentation/examples/appearance/grid/ytickformat/ytickformat_4_thumb.png)](documentation/GALLERY.md#ytickformat_4)  [![example_ytickformat_5](documentation/examples/appearance/grid/ytickformat/ytickformat_5_thumb.png)](documentation/GALLERY.md#ytickformat_5)  [![example_ztickformat_1](documentation/examples/appearance/grid/ztickformat/ztickformat_1_thumb.png)](documentation/GALLERY.md#ztickformat_1)  [![example_ztickformat_2](documentation/examples/appearance/grid/ztickformat/ztickformat_2_thumb.png)](documentation/GALLERY.md#ztickformat_2)  [![example_ztickformat_3](documentation/examples/appearance/grid/ztickformat/ztickformat_3_thumb.png)](documentation/GALLERY.md#ztickformat_3)  [![example_ztickformat_4](documentation/examples/appearance/grid/ztickformat/ztickformat_4_thumb.png)](documentation/GALLERY.md#ztickformat_4)  [![example_ztickformat_5](documentation/examples/appearance/grid/ztickformat/ztickformat_5_thumb.png)](documentation/GALLERY.md#ztickformat_5)  [![example_xtickangle_1](documentation/examples/appearance/grid/xtickangle/xtickangle_1_thumb.png)](documentation/GALLERY.md#xtickangle_1)  [![example_xtickangle_2](documentation/examples/appearance/grid/xtickangle/xtickangle_2_thumb.png)](documentation/GALLERY.md#xtickangle_2)  [![example_xtickangle_3](documentation/examples/appearance/grid/xtickangle/xtickangle_3_thumb.png)](documentation/GALLERY.md#xtickangle_3)  [![example_ytickangle_1](documentation/examples/appearance/grid/ytickangle/ytickangle_1_thumb.png)](documentation/GALLERY.md#ytickangle_1)  [![example_ytickangle_2](documentation/examples/appearance/grid/ytickangle/ytickangle_2_thumb.png)](documentation/GALLERY.md#ytickangle_2)  [![example_ytickangle_3](documentation/examples/appearance/grid/ytickangle/ytickangle_3_thumb.png)](documentation/GALLERY.md#ytickangle_3)  [![example_hold_1](documentation/examples/appearance/multiplot/hold/hold_1_thumb.png)](documentation/GALLERY.md#hold_1)  [![example_hold_2](documentation/examples/appearance/multiplot/hold/hold_2_thumb.png)](documentation/GALLERY.md#hold_2)  [![example_hold_3](documentation/examples/appearance/multiplot/hold/hold_3_thumb.png)](documentation/GALLERY.md#hold_3)  [![example_hold_4](documentation/examples/appearance/multiplot/hold/hold_4_thumb.png)](documentation/GALLERY.md#hold_4)  [![example_yyaxis_1](documentation/examples/appearance/multiplot/yyaxis/yyaxis_1_thumb.png)](documentation/GALLERY.md#yyaxis_1)  [![example_yyaxis_2](documentation/examples/appearance/multiplot/yyaxis/yyaxis_2_thumb.png)](documentation/GALLERY.md#yyaxis_2)  [![example_yyaxis_3](documentation/examples/appearance/multiplot/yyaxis/yyaxis_3_thumb.png)](documentation/GALLERY.md#yyaxis_3)  [![example_yyaxis_4](documentation/examples/appearance/multiplot/yyaxis/yyaxis_4_thumb.png)](documentation/GALLERY.md#yyaxis_4)  [![example_yyaxis_5](documentation/examples/appearance/multiplot/yyaxis/yyaxis_5_thumb.png)](documentation/GALLERY.md#yyaxis_5)  [![example_yyaxis_6](documentation/examples/appearance/multiplot/yyaxis/yyaxis_6_thumb.png)](documentation/GALLERY.md#yyaxis_6)  [![example_yyaxis_7](documentation/examples/appearance/multiplot/yyaxis/yyaxis_7_thumb.png)](documentation/GALLERY.md#yyaxis_7)  [![example_colororder_1](documentation/examples/appearance/multiplot/colororder/colororder_1_thumb.png)](documentation/GALLERY.md#colororder_1)  [![example_colororder_2](documentation/examples/appearance/multiplot/colororder/colororder_2_thumb.png)](documentation/GALLERY.md#colororder_2)  [![example_colororder_3](documentation/examples/appearance/multiplot/colororder/colororder_3_thumb.png)](documentation/GALLERY.md#colororder_3)  [![example_colororder_4](documentation/examples/appearance/multiplot/colororder/colororder_4_thumb.png)](documentation/GALLERY.md#colororder_4)  [![example_colororder_5](documentation/examples/appearance/multiplot/colororder/colororder_5_thumb.png)](documentation/GALLERY.md#colororder_5)  [![example_colororder_6](documentation/examples/appearance/multiplot/colororder/colororder_6_thumb.png)](documentation/GALLERY.md#colororder_6)  [![example_colororder_7](documentation/examples/appearance/multiplot/colororder/colororder_7_thumb.png)](documentation/GALLERY.md#colororder_7)  [![example_subplot_1](documentation/examples/appearance/multiplot/subplot/subplot_1_thumb.png)](documentation/GALLERY.md#subplot_1)  [![example_subplot_2](documentation/examples/appearance/multiplot/subplot/subplot_2_thumb.png)](documentation/GALLERY.md#subplot_2)  [![example_subplot_3](documentation/examples/appearance/multiplot/subplot/subplot_3_thumb.png)](documentation/GALLERY.md#subplot_3)  [![example_subplot_4](documentation/examples/appearance/multiplot/subplot/subplot_4_thumb.png)](documentation/GALLERY.md#subplot_4)  [![example_subplot_5](documentation/examples/appearance/multiplot/subplot/subplot_5_thumb.png)](documentation/GALLERY.md#subplot_5)  [![example_subplot_6](documentation/examples/appearance/multiplot/subplot/subplot_6_thumb.png)](documentation/GALLERY.md#subplot_6)  [![example_subplot_7](documentation/examples/appearance/multiplot/subplot/subplot_7_thumb.png)](documentation/GALLERY.md#subplot_7)  [![example_subplot_8](documentation/examples/appearance/multiplot/subplot/subplot_8_thumb.png)](documentation/GALLERY.md#subplot_8)  [![example_subplot_9](documentation/examples/appearance/multiplot/subplot/subplot_9_thumb.png)](documentation/GALLERY.md#subplot_9)  [![example_subplot_10](documentation/examples/appearance/multiplot/subplot/subplot_10_thumb.png)](documentation/GALLERY.md#subplot_10)  [![example_subplot_11](documentation/examples/appearance/multiplot/subplot/subplot_11_thumb.png)](documentation/GALLERY.md#subplot_11)  [![example_subplot_12](documentation/examples/appearance/multiplot/subplot/subplot_12_thumb.png)](documentation/GALLERY.md#subplot_12)  [![example_subplot_13](documentation/examples/appearance/multiplot/subplot/subplot_13_thumb.png)](documentation/GALLERY.md#subplot_13)  [![example_tiledlayout_1](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_1_thumb.png)](documentation/GALLERY.md#tiledlayout_1)  [![example_tiledlayout_2](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_2_thumb.png)](documentation/GALLERY.md#tiledlayout_2)  [![example_tiledlayout_3](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_3_thumb.png)](documentation/GALLERY.md#tiledlayout_3)  [![example_tiledlayout_4](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_4_thumb.png)](documentation/GALLERY.md#tiledlayout_4)  [![example_tiledlayout_5](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_5_thumb.png)](documentation/GALLERY.md#tiledlayout_5)  [![example_tiledlayout_6](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_6_thumb.png)](documentation/GALLERY.md#tiledlayout_6)  [![example_tiledlayout_7](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_7_thumb.png)](documentation/GALLERY.md#tiledlayout_7)  [![example_tiledlayout_8](documentation/examples/appearance/multiplot/tiledlayout/tiledlayout_8_thumb.png)](documentation/GALLERY.md#tiledlayout_8)  [![example_colormap_1](documentation/examples/appearance/colormaps/colormap/colormap_1_thumb.png)](documentation/GALLERY.md#colormap_1)  [![example_colormap_2](documentation/examples/appearance/colormaps/colormap/colormap_2_thumb.png)](documentation/GALLERY.md#colormap_2)  [![example_colormap_3](documentation/examples/appearance/colormaps/colormap/colormap_3_thumb.png)](documentation/GALLERY.md#colormap_3)  [![example_colormap_4](documentation/examples/appearance/colormaps/colormap/colormap_4_thumb.png)](documentation/GALLERY.md#colormap_4)  [![example_colormap_5](documentation/examples/appearance/colormaps/colormap/colormap_5_thumb.png)](documentation/GALLERY.md#colormap_5)  [![example_colormap_6](documentation/examples/appearance/colormaps/colormap/colormap_6_thumb.png)](documentation/GALLERY.md#colormap_6)  [![example_colormap_7](documentation/examples/appearance/colormaps/colormap/colormap_7_thumb.png)](documentation/GALLERY.md#colormap_7)  [![example_colormap_8](documentation/examples/appearance/colormaps/colormap/colormap_8_thumb.png)](documentation/GALLERY.md#colormap_8)  [![example_colormap_9](documentation/examples/appearance/colormaps/colormap/colormap_9_thumb.png)](documentation/GALLERY.md#colormap_9)  [![example_colorbar_1](documentation/examples/appearance/colormaps/colorbar/colorbar_1_thumb.png)](documentation/GALLERY.md#colorbar_1)  [![example_colorbar_2](documentation/examples/appearance/colormaps/colorbar/colorbar_2_thumb.png)](documentation/GALLERY.md#colorbar_2)  [![example_colorbar_3](documentation/examples/appearance/colormaps/colorbar/colorbar_3_thumb.png)](documentation/GALLERY.md#colorbar_3)  [![example_colorbar_4](documentation/examples/appearance/colormaps/colorbar/colorbar_4_thumb.png)](documentation/GALLERY.md#colorbar_4)  [![example_colorbar_5](documentation/examples/appearance/colormaps/colorbar/colorbar_5_thumb.png)](documentation/GALLERY.md#colorbar_5)  [![example_colorbar_6](documentation/examples/appearance/colormaps/colorbar/colorbar_6_thumb.png)](documentation/GALLERY.md#colorbar_6)  [![example_colorbar_7](documentation/examples/appearance/colormaps/colorbar/colorbar_7_thumb.png)](documentation/GALLERY.md#colorbar_7)  [![example_rgbplot_1](documentation/examples/appearance/colormaps/rgbplot/rgbplot_1_thumb.png)](documentation/GALLERY.md#rgbplot_1)  [![example_rgbplot_2](documentation/examples/appearance/colormaps/rgbplot/rgbplot_2_thumb.png)](documentation/GALLERY.md#rgbplot_2)  [![example_view_1](documentation/examples/appearance/camera/view/view_1_thumb.png)](documentation/GALLERY.md#view_1)  [![example_view_2](documentation/examples/appearance/camera/view/view_2_thumb.png)](documentation/GALLERY.md#view_2)  [![example_view_3](documentation/examples/appearance/camera/view/view_3_thumb.png)](documentation/GALLERY.md#view_3)  [![example_view_4](documentation/examples/appearance/camera/view/view_4_thumb.png)](documentation/GALLERY.md#view_4)  [![example_view_5](documentation/examples/appearance/camera/view/view_5_thumb.png)](documentation/GALLERY.md#view_5)  [![example_view_6](documentation/examples/appearance/camera/view/view_6_thumb.png)](documentation/GALLERY.md#view_6)  [![example_lighting_1](documentation/examples/appearance/camera/lighting/lighting_1_thumb.png)](documentation/GALLERY.md#lighting_1)  [![example_lighting_2](documentation/examples/appearance/camera/lighting/lighting_2_thumb.png)](documentation/GALLERY.md#lighting_2)  [![example_lighting_3](documentation/examples/appearance/camera/lighting/lighting_3_thumb.png)](documentation/GALLERY.md#lighting_3)  [![example_lighting_4](documentation/examples/appearance/camera/lighting/lighting_4_thumb.png)](documentation/GALLERY.md#lighting_4)  [![example_lighting_5](documentation/examples/appearance/camera/lighting/lighting_5_thumb.png)](documentation/GALLERY.md#lighting_5)  [![example_lighting_6](documentation/examples/appearance/camera/lighting/lighting_6_thumb.png)](documentation/GALLERY.md#lighting_6)  [![example_figure_1](documentation/examples/appearance/figure/figure_1_thumb.png)](documentation/GALLERY.md#figure_1)  [![example_figure_2](documentation/examples/appearance/figure/figure_2_thumb.png)](documentation/GALLERY.md#figure_2)  [![example_figure_3](documentation/examples/appearance/figure/figure_3_thumb.png)](documentation/GALLERY.md#figure_3)  [![example_line_spec_1](documentation/examples/appearance/line_spec/line_spec_1_thumb.png)](documentation/GALLERY.md#line_spec_1)  [![example_axes_1](documentation/examples/appearance/axes/axes_1_thumb.png)](documentation/GALLERY.md#axes_1)  [![example_axes_2](documentation/examples/appearance/axes/axes_2_thumb.png)](documentation/GALLERY.md#axes_2)  [![example_axes_3](documentation/examples/appearance/axes/axes_3_thumb.png)](documentation/GALLERY.md#axes_3)  [![example_axes_4](documentation/examples/appearance/axes/axes_4_thumb.png)](documentation/GALLERY.md#axes_4)  [![example_cla_1](documentation/examples/appearance/cla/cla_1_thumb.png)](documentation/GALLERY.md#cla_1)  [![example_cla_2](documentation/examples/appearance/cla/cla_2_thumb.png)](documentation/GALLERY.md#cla_2)  [![example_cla_3](documentation/examples/appearance/cla/cla_3_thumb.png)](documentation/GALLERY.md#cla_3)  [![example_save_1](documentation/examples/exporting/save/save_1_thumb.png)](documentation/GALLERY.md#save_1)  [![example_save_2](documentation/examples/exporting/save/save_2_thumb.png)](documentation/GALLERY.md#save_2)  [![example_save_3](documentation/examples/exporting/save/save_3_thumb.png)](documentation/GALLERY.md#save_3)  [![example_save_4](documentation/examples/exporting/save/save_4_thumb.png)](documentation/GALLERY.md#save_4)  [![example_save_5](documentation/examples/exporting/save/save_5_thumb.png)](documentation/GALLERY.md#save_5)  [![example_save_6](documentation/examples/exporting/save/save_6_thumb.png)](documentation/GALLERY.md#save_6)  [![example_save_7](documentation/examples/exporting/save/save_7_thumb.png)](documentation/GALLERY.md#save_7)  [![example_save_8](documentation/examples/exporting/save/save_8_thumb.png)](documentation/GALLERY.md#save_8)  